==> 0.16.0.tar.gz: test/services/title_test.dart <==
import 'dart:html' as dom;
import 'package:angular/angular.dart';
import 'package:angular_test/angular_test.dart';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';
import 'title_test.template.dart' as self;

/// The test component.
@Component(
    providers: [ngxProviders],
    selector: 'test-component',
    template: '<div></div>')
class TestComponent {
  TestComponent(this.app, this.title);
  final Application app;
  final Title title;
}

/// Tests the features of the [Title] class.
void main() => group('Title', () {
      final testBed =
          NgTestBed.forComponent<TestComponent>(self.TestComponentNgFactory);
      tearDown(disposeAnyRunningTest);

      group('.text', () {
        test(
            'should return the document title, without the application name appended',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c.title.text = 'Foo Bar');
          expect(fixture.assertOnlyInstance.title.text,
              dom.document.title.split(' | ').first);
        });

        test(
            'should set the document title, with the application name appended',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c.title.text = 'Bar');
          final component = fixture.assertOnlyInstance;
          expect(dom.document.title,
              '${component.title.text} | ${component.app.name}');
        });
      });

      group('.setText()', () {
        test(
            'should set the document title, without appending the application name',
            () async {
          final fixture = await testBed.create();
          await fixture
              .update((c) => c.title.setText('Baz', appendAppName: false));
          expect(dom.document.title, fixture.assertOnlyInstance.title.text);
        });

        test('should set the document title, appending the application name',
            () async {
          final fixture = await testBed.create();
          await fixture
              .update((c) => c.title.setText('Qux', appendAppName: true));
          final component = fixture.assertOnlyInstance;
          expect(dom.document.title,
              '${component.title.text} | ${component.app.name}');
        });
      });
    });

==> 0.17.0.tar.gz: test/services/title_test.dart <==
import 'dart:html' as dom;
import 'package:angular/angular.dart';
import 'package:angular_router/testing.dart';
import 'package:angular_test/angular_test.dart';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';
import 'title_test.template.dart' as self;

/// The test component.
@Component(
    providers: [ngxProviders, routerProvidersTest],
    selector: 'test-component',
    template: '<div></div>')
class TestComponent {
  TestComponent(this.app, this.title);
  final Application app;
  final Title title;
}

/// Tests the features of the [Title] class.
void main() => group('Title', () {
      final testBed =
          NgTestBed.forComponent<TestComponent>(self.TestComponentNgFactory);
      tearDown(disposeAnyRunningTest);

      group('.text', () {
        test(
            'should return the document title, without the application name appended',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c.title.text = 'Foo Bar');
          expect(fixture.assertOnlyInstance.title.text,
              dom.document.title.split(' | ').first);
        });

        test(
            'should set the document title, with the application name appended',
            () async {
          final fixture = await testBed.create();
          await fixture.update((c) => c.title.text = 'Bar');
          final component = fixture.assertOnlyInstance;
          expect(dom.document.title,
              '${component.title.text} | ${component.app.name}');
        });
      });

      group('.setText()', () {
        test(
            'should set the document title, without appending the application name',
            () async {
          final fixture = await testBed.create();
          await fixture
              .update((c) => c.title.setText('Baz', appendAppName: false));
          expect(dom.document.title, fixture.assertOnlyInstance.title.text);
        });

        test('should set the document title, appending the application name',
            () async {
          final fixture = await testBed.create();
          await fixture
              .update((c) => c.title.setText('Qux', appendAppName: true));
          final component = fixture.assertOnlyInstance;
          expect(dom.document.title,
              '${component.title.text} | ${component.app.name}');
        });
      });
    });
